import ast

from PyQt5 import QtWidgets
from sklearn.linear_model.ridge import Ridge
from sklearn.linear_model.ridge import RidgeCV

from point_spectra_gui.ui.Ridge import Ui_Form
from point_spectra_gui.util.Modules import Modules


class Ui_Form(Ui_Form, Ridge, RidgeCV, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.groupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        ridge = Ridge()

        self.alphaDoubleSpinBox.setValue(ridge.alpha)
        self.fitInterceptCheckBox.setChecked(ridge.fit_intercept)
        self.normalizeCheckBox.setChecked(ridge.normalize)
        self.toleranceDoubleSpinBox.setValue(ridge.tol)

    def run(self):
        params = {'alpha': self.alphaDoubleSpinBox.value(),
                  'copy_X': True,
                  'fit_intercept': self.fitInterceptCheckBox.isChecked(),
                  'normalize': self.normalizeCheckBox.isChecked(),
                  'solver': 'auto',
                  'tol': self.toleranceDoubleSpinBox.value(),
                  'random_state': None
                  }
        return params, self.getChangedValues(params, Ridge())


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setTitle("")
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.reductionMethodLabel = QtWidgets.QLabel(self.formGroupBox)
        self.reductionMethodLabel.setObjectName("reductionMethodLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.reductionMethodLabel)
        self.DimRedList = QtWidgets.QListWidget(self.formGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.DimRedList.sizePolicy().hasHeightForWidth())
        self.DimRedList.setSizePolicy(sizePolicy)
        self.DimRedList.setMinimumSize(QtCore.QSize(0, 0))
        self.DimRedList.setMaximumSize(QtCore.QSize(16777215, 50))
        self.DimRedList.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.DimRedList.setObjectName("DimRedList")
        item = QtWidgets.QListWidgetItem()
        self.DimRedList.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.DimRedList.addItem(item)
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.DimRedList)
        self.numOfComponenetsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.numOfComponenetsLabel.setObjectName("numOfComponenetsLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.numOfComponenetsLabel)
        self.numOfComponenetsLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.numOfComponenetsLineEdit.setObjectName("numOfComponenetsLineEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.numOfComponenetsLineEdit)
        self.regrLabel = QtWidgets.QLabel(self.formGroupBox)
        self.regrLabel.setObjectName("regrLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.regrLabel)
        self.regression_list = QtWidgets.QListWidget(self.formGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.regression_list.sizePolicy().hasHeightForWidth())
        self.regression_list.setSizePolicy(sizePolicy)
        self.regression_list.setMaximumSize(QtCore.QSize(16777215, 75))
        self.regression_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.regression_list.setObjectName("regression_list")
        item = QtWidgets.QListWidgetItem()
        self.regression_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.regression_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.regression_list.addItem(item)
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.regression_list)
        self.corrLabel = QtWidgets.QLabel(self.formGroupBox)
        self.corrLabel.setObjectName("corrLabel")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.corrLabel)
        self.CorrelationList = QtWidgets.QListWidget(self.formGroupBox)
        self.CorrelationList.setMaximumSize(QtCore.QSize(16777215, 75))
        self.CorrelationList.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.CorrelationList.setObjectName("CorrelationList")
        item = QtWidgets.QListWidgetItem()
        self.CorrelationList.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.CorrelationList.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.CorrelationList.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.CorrelationList.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.CorrelationList.addItem(item)
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.CorrelationList)
        self.theta0Label = QtWidgets.QLabel(self.formGroupBox)
        self.theta0Label.setObjectName("theta0Label")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.theta0Label)
        self.theta0LineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.theta0LineEdit.setObjectName("theta0LineEdit")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.theta0LineEdit)
        self.ThetaL_Label = QtWidgets.QLabel(self.formGroupBox)
        self.ThetaL_Label.setObjectName("ThetaL_Label")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.ThetaL_Label)
        self.ThetaL = QtWidgets.QLineEdit(self.formGroupBox)
        self.ThetaL.setObjectName("ThetaL")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.ThetaL)
        self.ThetaU_Label = QtWidgets.QLabel(self.formGroupBox)
        self.ThetaU_Label.setObjectName("ThetaU_Label")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.ThetaU_Label)
        self.ThetaU = QtWidgets.QLineEdit(self.formGroupBox)
        self.ThetaU.setObjectName("ThetaU")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.ThetaU)
        self.randomStartLabel = QtWidgets.QLabel(self.formGroupBox)
        self.randomStartLabel.setObjectName("randomStartLabel")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.LabelRole, self.randomStartLabel)
        self.randomStartLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.randomStartLineEdit.setObjectName("randomStartLineEdit")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.FieldRole, self.randomStartLineEdit)
        self.normalize_label = QtWidgets.QLabel(self.formGroupBox)
        self.normalize_label.setObjectName("normalize_label")
        self.formLayout.setWidget(10, QtWidgets.QFormLayout.LabelRole, self.normalize_label)
        self.normalize_list = QtWidgets.QListWidget(self.formGroupBox)
        self.normalize_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.normalize_list.setObjectName("normalize_list")
        item = QtWidgets.QListWidgetItem()
        self.normalize_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.normalize_list.addItem(item)
        self.formLayout.setWidget(10, QtWidgets.QFormLayout.FieldRole, self.normalize_list)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.formGroupBox.setToolTip(("<html><head/><body><p>Gaussian Processes (GP) are a generic supervised learning method designed to solve regression and probabilistic classification problems.</p><p><br/></p><p><span style=\" font-weight:600;\">The advantages of Gaussian processes are:</span></p><p>The prediction interpolates the observations (at least for regular kernels).</p><p>The prediction is probabilistic (Gaussian) so that one can compute empirical confidence intervals and decide based on those if one should refit (online fitting, adaptive fitting) the prediction in some region of interest.</p><p>Versatile: different kernels can be specified. Common kernels are provided, but it is also possible to specify custom kernels.</p><p><br/></p><p><span style=\" font-weight:600;\">The disadvantages of Gaussian processes include:</span></p><p>They are not sparse, i.e., they use the whole samples/features information to perform the prediction.</p><p>They lose efficiency in high dimensional spaces - namely when the number of features exceeds a few dozens.</p></body></html>"))
        self.reductionMethodLabel.setText(("Choose dimensionality reduction method:"))
        __sortingEnabled = self.DimRedList.isSortingEnabled()
        self.DimRedList.setSortingEnabled(False)
        item = self.DimRedList.item(0)
        item.setText(("PCA"))
        item = self.DimRedList.item(1)
        item.setText(("FastICA"))
        self.DimRedList.setSortingEnabled(__sortingEnabled)
        self.numOfComponenetsLabel.setText(("Number of Components"))
        self.numOfComponenetsLineEdit.setText(("1,2,3,4,5,6,7,8,9,10,11,12,13,14,15"))
        self.regrLabel.setText(("Regression Types"))
        __sortingEnabled = self.regression_list.isSortingEnabled()
        self.regression_list.setSortingEnabled(False)
        item = self.regression_list.item(0)
        item.setText(("Linear"))
        item = self.regression_list.item(1)
        item.setText(("Constant"))
        item = self.regression_list.item(2)
        item.setText(("Quadratic"))
        self.regression_list.setSortingEnabled(__sortingEnabled)
        self.corrLabel.setText(("Correlation Types"))
        __sortingEnabled = self.CorrelationList.isSortingEnabled()
        self.CorrelationList.setSortingEnabled(False)
        item = self.CorrelationList.item(0)
        item.setText(("Squared Exponential"))
        item = self.CorrelationList.item(1)
        item.setText(("Absolute Exponential"))
        item = self.CorrelationList.item(2)
        item.setText(("Generalized Exponential"))
        item = self.CorrelationList.item(3)
        item.setText(("Cubic"))
        item = self.CorrelationList.item(4)
        item.setText(("Linear"))
        self.CorrelationList.setSortingEnabled(__sortingEnabled)
        self.theta0Label.setText(("Theta"))
        self.theta0LineEdit.setText(("0.1"))
        self.ThetaL_Label.setText(("Theta - Lower Bound"))
        self.ThetaU_Label.setText(("Theta - Upper Bound"))
        self.randomStartLabel.setText(("# of random starts for MLE"))
        self.normalize_label.setText(("Normalize"))
        __sortingEnabled = self.normalize_list.isSortingEnabled()
        self.normalize_list.setSortingEnabled(False)
        item = self.normalize_list.item(0)
        item.setText(("True"))
        item = self.normalize_list.item(1)
        item.setText(("False"))
        self.normalize_list.setSortingEnabled(__sortingEnabled)


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets, QtCore
from sklearn.svm.classes import SVR

from point_spectra_gui.ui.cv_SVR import Ui_Form
from point_spectra_gui.util.Modules import Modules


class Ui_Form(Ui_Form, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.formGroupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        svr = SVR()
        svr.kernel = 'rbf'
        svr.degree = 3
        svr.gamma = 'auto'
        svr.coef0 = 0.0
        svr.tol = 1e-3
        svr.C = 1.0
        svr.epsilon = 0.1
        svr.shrinking = True
        svr.cache_size = 200
        svr.verbose = False
        svr.max_iter = -1

        self.cLineEdit.setText(str(svr.C))
        self.epsilonLineEdit.setText(str(svr.epsilon))
        self.kernel_list.setCurrentItem(self.kernel_list.findItems('Radial Basis Function', QtCore.Qt.MatchExactly)[0])
        self.degreeLineEdit.setText(str(svr.degree))
        self.coeff0LineEdit.setText(str(svr.coef0))
        self.shrinking_list.setCurrentItem(self.shrinking_list.findItems(str(svr.shrinking), QtCore.Qt.MatchExactly)[0])
        self.toleranceLineEdit.setText(str(svr.tol))
        self.maxIterationsLineEdit.setText(str(svr.max_iter))

    def run(self):
        kernels = [str(i.text()) for i in self.kernel_list.selectedItems()]
        shrinking_items = [i.text() == 'True' for i in self.shrinking_list.selectedItems()]
        params = {'C': [float(i) for i in self.cLineEdit.text().split(',')],
                  'epsilon': [float(i) for i in self.epsilonLineEdit.text().split(',')],
                  'kernel': kernels,
                  'degree': [int(i) for i in self.degreeLineEdit.text().split(',')],
                  'gamma': ['auto'],
                  'coef0': [float(i) for i in self.coeff0LineEdit.text().split(',')],
                  'shrinking': shrinking_items,
                  'tol': [float(i) for i in self.toleranceLineEdit.text().split(',')],
                  'cache_size': [200],
                  'verbose': [True],
                  'max_iter': [int(i) for i in self.maxIterationsLineEdit.text().split(',')]}
        modelkey = str(params)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.formLayout = QtWidgets.QFormLayout(self.groupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.n_clust_label = QtWidgets.QLabel(self.groupBox)
        self.n_clust_label.setObjectName("n_clust_label")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.n_clust_label)
        self.n_clust_spin = QtWidgets.QSpinBox(self.groupBox)
        self.n_clust_spin.setObjectName("n_clust_spin")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.n_clust_spin)
        self.n_runs_label = QtWidgets.QLabel(self.groupBox)
        self.n_runs_label.setObjectName("n_runs_label")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.n_runs_label)
        self.n_runs_spin = QtWidgets.QSpinBox(self.groupBox)
        self.n_runs_spin.setObjectName("n_runs_spin")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.n_runs_spin)
        self.n_iter_label = QtWidgets.QLabel(self.groupBox)
        self.n_iter_label.setObjectName("n_iter_label")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.n_iter_label)
        self.n_iter_spin = QtWidgets.QSpinBox(self.groupBox)
        self.n_iter_spin.setObjectName("n_iter_spin")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.n_iter_spin)
        self.tol_label = QtWidgets.QLabel(self.groupBox)
        self.tol_label.setObjectName("tol_label")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.tol_label)
        self.tol_dspin = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.tol_dspin.setDecimals(6)
        self.tol_dspin.setObjectName("tol_dspin")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.tol_dspin)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.n_clust_label.setText(("# of clusters"))
        self.n_runs_label.setText(("# of runs"))
        self.n_iter_label.setText(("Max. # of iterations"))
        self.tol_label.setText(("Tolerance"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.formLayout = QtWidgets.QFormLayout(self.groupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.n_clust_label = QtWidgets.QLabel(self.groupBox)
        self.n_clust_label.setObjectName("n_clust_label")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.n_clust_label)
        self.n_clust_spin = QtWidgets.QSpinBox(self.groupBox)
        self.n_clust_spin.setObjectName("n_clust_spin")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.n_clust_spin)
        self.n_runs_label = QtWidgets.QLabel(self.groupBox)
        self.n_runs_label.setObjectName("n_runs_label")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.n_runs_label)
        self.n_runs_spin = QtWidgets.QSpinBox(self.groupBox)
        self.n_runs_spin.setObjectName("n_runs_spin")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.n_runs_spin)
        self.affinity_label = QtWidgets.QLabel(self.groupBox)
        self.affinity_label.setObjectName("affinity_label")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.affinity_label)
        self.affinity_comboBox = QtWidgets.QComboBox(self.groupBox)
        self.affinity_comboBox.setObjectName("affinity_comboBox")
        self.affinity_comboBox.addItem("")
        self.affinity_comboBox.addItem("")
        self.affinity_comboBox.addItem("")
        self.affinity_comboBox.addItem("")
        self.affinity_comboBox.addItem("")
        self.affinity_comboBox.addItem("")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.affinity_comboBox)
        self.gamma_label = QtWidgets.QLabel(self.groupBox)
        self.gamma_label.setObjectName("gamma_label")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.gamma_label)
        self.gamma_dspin = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.gamma_dspin.setObjectName("gamma_dspin")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.gamma_dspin)
        self.n_neighbors_label = QtWidgets.QLabel(self.groupBox)
        self.n_neighbors_label.setObjectName("n_neighbors_label")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.n_neighbors_label)
        self.n_neighbors_spin = QtWidgets.QSpinBox(self.groupBox)
        self.n_neighbors_spin.setObjectName("n_neighbors_spin")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.n_neighbors_spin)
        self.coef0_label = QtWidgets.QLabel(self.groupBox)
        self.coef0_label.setObjectName("coef0_label")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.coef0_label)
        self.coef0_spin = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.coef0_spin.setObjectName("coef0_spin")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.coef0_spin)
        self.degree_label = QtWidgets.QLabel(self.groupBox)
        self.degree_label.setObjectName("degree_label")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.degree_label)
        self.degree_spin = QtWidgets.QSpinBox(self.groupBox)
        self.degree_spin.setObjectName("degree_spin")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.degree_spin)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.n_clust_label.setText(("# of clusters"))
        self.n_runs_label.setText(("# of runs"))
        self.affinity_label.setText(("Affinity kernel"))
        self.affinity_comboBox.setItemText(0, ("Radial Basis Function"))
        self.affinity_comboBox.setItemText(1, ("Nearest Neighbors"))
        self.affinity_comboBox.setItemText(2, ("Sigmoid"))
        self.affinity_comboBox.setItemText(3, ("Polynomial"))
        self.affinity_comboBox.setItemText(4, ("Linear"))
        self.affinity_comboBox.setItemText(5, ("Cosine"))
        self.gamma_label.setText(("Gamma"))
        self.n_neighbors_label.setText(("# neighbors"))
        self.coef0_label.setText(("Zero Coefficient"))
        self.degree_label.setText(("Degree"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets, QtCore
from libpysat.regression import sm

from point_spectra_gui.ui.SubmodelBlend import Ui_Form
from point_spectra_gui.util.Modules import Modules
import numpy as np

class subWidgets:
    def __init__(self, predictionComboBox, minLabel, minSpinBox, maxLabel, maxSpinBox):
        self.predictionComboBox = predictionComboBox
        self.minLabel = minLabel
        self.minSpinBox = minSpinBox
        self.maxLabel = maxLabel
        self.maxSpinBox = maxSpinBox

    def get_predictionComboBox(self):
        return self.predictionComboBox

    def get_minSpinBox(self):
        return self.minSpinBox

    def get_maxSpinBox(self):
        return self.maxSpinBox

    def setHidden(self, bool):
        self.predictionComboBox.setHidden(bool)
        self.minLabel.setHidden(bool)
        self.minSpinBox.setHidden(bool)
        self.maxLabel.setHidden(bool)
        self.maxSpinBox.setHidden(bool)

    def getValues(self):
        return [self.predictionComboBox.currentText(), [float(self.minSpinBox.value()), float(self.maxSpinBox.value())]]

    def setValue(self, int_):
        self.minSpinBox.setValue(int_)
        self.maxSpinBox.setValue(int_)

    def spinBox(self, int_):
        if int_ == 0:
            return self.minSpinBox
        elif int_ == 1:
            return self.maxSpinBox
        else:
            return "Not a valid number"


class SubmodelBlend(Ui_Form, Modules):
    def __init__(self):
        super().__init__()
        self.subwidgets = []


    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        Modules.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox


    def connectWidgets(self):
        self.index_spin.setHidden(True)
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.getPredictions()
        self.chooseDataComboBox.currentIndexChanged.connect(self.getPredictions)
        self.setupWidgets()
        self.setHidden(self.subwidgets)


        try:
            self.setComboBox(self.referencePredictionComboBox, self.predictnames)
            self.setComboBox(self.lowPredictionComboBox, self.predictnames)
            self.setComboBox(self.highPredictionComboBox, self.predictnames)
            self.setComboBox(self.optimizeSubRangesComboBox,
                             self.data[self.chooseDataComboBox.currentText()].df['comp'].columns.values)
        except:
            pass
        self.addSubPushButton.clicked.connect(self.addSubmodel_pushed)
        self.deleteSubPushButton.clicked.connect(self.deleteSubmodel_pushed)
        self.optimizeSubRangesLabel.setHidden(True)
        self.optimizeSubRangesComboBox.setHidden(True)

    def setHidden(self, list):
        for i in range(0, len(list)):
            if i < self.index_spin.value():
                list[i].setHidden(False)
            else:
                list[i].setHidden(True)

    def clearPredictions(self):
        self.setComboBox(self.referencePredictionComboBox, [''])
        self.setComboBox(self.lowPredictionComboBox, [''])
        self.setComboBox(self.highPredictionComboBox, [''])
        for i in self.subwidgets:
            self.setComboBox(i.get_predictionComboBox(), [''])

    def getPredictions(self):
        #self.clearPredictions()
        try:
            self.predictnames = self.data[self.chooseDataComboBox.currentText()].df['predict'].columns.values
        except:
            self.predictnames = ['']
        self.setComboBox(self.referencePredictionComboBox, self.predictnames)
        self.setComboBox(self.lowPredictionComboBox, self.predictnames)
        self.setComboBox(self.highPredictionComboBox, self.predictnames)
        for i in self.subwidgets:
            self.setComboBox(i.get_predictionComboBox(), self.predictnames)



        if self.optimizeSubRangesCheckBox.isChecked():
            try:
                self.setComboBox(self.optimizeSubRangesComboBox,
                                 self.data[self.chooseDataComboBox.currentText()].df['comp'].columns.values)
            except:
                self.setComboBox(self.optimizeSubRangesComboBox, ['No Compositions'])

    def setup(self):
        blendranges = []
        submodel_blend_names = []
        submodel_predictions = []
        datakey = self.chooseDataComboBox.currentText()
        refcol = ('comp', self.optimizeSubRangesComboBox.currentText())

        # start with the low model
        blendranges.append([-9999, float(self.lowPredictionMaxSpinBox.value())])

        # append the intermediate submodels
        for i in range(0, self.index_spin.value()):
            temp_vals = self.subwidgets[i].getValues()
            blendranges.append(temp_vals[1])

        # append the high model
        blendranges.append([float(self.highPredictionMinSpinBox.value()), 9999])


        sm_obj = sm.sm(blendranges)

        # save the blended predictions
        try:
            self.data[datakey].df[('predict', 'Blended-Predict ' + str(sm_obj.blendranges))] = 99999
        except:
            pass

    def run(self):
        blendranges = []
        submodel_blend_names = []
        submodel_predictions = []
        datakey = self.chooseDataComboBox.currentText()
        refcol = ('comp', self.optimizeSubRangesComboBox.currentText())

        # start with the low model
        blendranges.append([-9999, float(self.lowPredictionMaxSpinBox.value())])
        submodel_blend_names.append(self.lowPredictionComboBox.currentText())
        submodel_predictions.append(self.data[datakey].df[('predict', self.lowPredictionComboBox.currentText())])

        # append the intermediate submodels
        for i in range(0, self.index_spin.value()):
            temp_vals = self.subwidgets[i].getValues()
            blendranges.append(temp_vals[1])
            submodel_blend_names.append(temp_vals[0])
            submodel_predictions.append(self.data[datakey].df[('predict', temp_vals[0])])

        # append the high model
        blendranges.append([float(self.highPredictionMinSpinBox.value()), 9999])
        submodel_blend_names.append(self.highPredictionComboBox.currentText())
        submodel_predictions.append(self.data[datakey].df[('predict', self.highPredictionComboBox.currentText())])

        # append the reference model as a catch-all
        submodel_blend_names.append(self.referencePredictionComboBox.currentText())
        submodel_predictions.append(self.data[datakey].df[('predict', self.referencePredictionComboBox.currentText())])

        if self.optimizeSubRangesCheckBox.isChecked():
            truevals = self.data[datakey].df[refcol]
        else:
            truevals = None

        sm_obj = sm.sm(blendranges)
        # optimize blending if reference data is provided
        if truevals is not None:
            predictions_blended = sm_obj.do_blend(np.array(submodel_predictions), truevals=truevals)
        else:
            # otherwise just blend the predictions together
            predictions_blended = sm_obj.do_blend(np.array(submodel_predictions))

        # save the blended predictions
        self.data[datakey].df[('predict', 'Blended-Predict ' + str(sm_obj.blendranges))] = predictions_blended


    def addSubmodel_pushed(self):
        if self.index_spin.value() < len(self.subwidgets):
            self.subwidgets[self.index_spin.value()].setHidden(False)
            self.setComboBox(self.subwidgets[self.index_spin.value()].get_predictionComboBox(), self.predictnames)
            self.index_spin.setValue(self.index_spin.value()+1)
        else:
            print("Cannot add more submodels")

    def deleteSubmodel_pushed(self):
        if self.index_spin.value() > 0:
            self.index_spin.setValue(self.index_spin.value() - 1)
            self.subwidgets[self.index_spin.value()].setHidden(True)
            self.subwidgets[self.index_spin.value()].setValue(0)

        else:
            print("Cannot delete any more submodels")

    def setupWidgets(self):
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox, self.minLabel, self.minSpinBox, self.maxLabel, self.maxSpinBox))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_2, self.minLabel_2, self.minSpinBox_2, self.maxLabel_2,
                       self.maxSpinBox_2))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_3, self.minLabel_3, self.minSpinBox_3, self.maxLabel_3,
                       self.maxSpinBox_3))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_4, self.minLabel_4, self.minSpinBox_4, self.maxLabel_4,
                       self.maxSpinBox_4))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_5, self.minLabel_5, self.minSpinBox_5, self.maxLabel_5,
                       self.maxSpinBox_5))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_6, self.minLabel_6, self.minSpinBox_6, self.maxLabel_6,
                       self.maxSpinBox_6))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_7, self.minLabel_7, self.minSpinBox_7, self.maxLabel_7,
                       self.maxSpinBox_7))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_8, self.minLabel_8, self.minSpinBox_8, self.maxLabel_8,
                       self.maxSpinBox_8))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_9, self.minLabel_9, self.minSpinBox_9, self.maxLabel_9,
                       self.maxSpinBox_9))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_10, self.minLabel_10, self.minSpinBox_10, self.maxLabel_10,
                       self.maxSpinBox_10))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_11, self.minLabel_11, self.minSpinBox_11, self.maxLabel_11,
                       self.maxSpinBox_11))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_12, self.minLabel_12, self.minSpinBox_12, self.maxLabel_12,
                       self.maxSpinBox_12))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_13, self.minLabel_13, self.minSpinBox_13, self.maxLabel_13,
                       self.maxSpinBox_13))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_14, self.minLabel_14, self.minSpinBox_14, self.maxLabel_14,
                       self.maxSpinBox_14))
        self.subwidgets.append(
            subWidgets(self.PredictionComboBox_15, self.minLabel_15, self.minSpinBox_15, self.maxLabel_15,
                       self.maxSpinBox_15))


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = SubmodelBlend()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.alphaLabel = QtWidgets.QLabel(self.formGroupBox)
        self.alphaLabel.setObjectName("alphaLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.alphaLabel)
        self.minalpha_spin = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.minalpha_spin.setDecimals(20)
        self.minalpha_spin.setMaximum(999999999.0)
        self.minalpha_spin.setObjectName("minalpha_spin")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.minalpha_spin)
        self.maxalpha_label = QtWidgets.QLabel(self.formGroupBox)
        self.maxalpha_label.setObjectName("maxalpha_label")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.maxalpha_label)
        self.maxalpha_spin = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.maxalpha_spin.setDecimals(20)
        self.maxalpha_spin.setMaximum(999999999.0)
        self.maxalpha_spin.setObjectName("maxalpha_spin")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.maxalpha_spin)
        self.nalpha_label = QtWidgets.QLabel(self.formGroupBox)
        self.nalpha_label.setToolTip("")
        self.nalpha_label.setObjectName("nalpha_label")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.nalpha_label)
        self.nalpha_spin = QtWidgets.QSpinBox(self.formGroupBox)
        self.nalpha_spin.setToolTip("")
        self.nalpha_spin.setMaximum(999999999)
        self.nalpha_spin.setObjectName("nalpha_spin")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.nalpha_spin)
        self.max_iterLabel = QtWidgets.QLabel(self.formGroupBox)
        self.max_iterLabel.setObjectName("max_iterLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.max_iterLabel)
        self.max_iterLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.max_iterLineEdit.setObjectName("max_iterLineEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.max_iterLineEdit)
        self.fit_interceptLabel = QtWidgets.QLabel(self.formGroupBox)
        self.fit_interceptLabel.setObjectName("fit_interceptLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.fit_interceptLabel)
        self.fit_intercept_list = QtWidgets.QListWidget(self.formGroupBox)
        self.fit_intercept_list.setMaximumSize(QtCore.QSize(16777215, 50))
        self.fit_intercept_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.fit_intercept_list.setObjectName("fit_intercept_list")
        item = QtWidgets.QListWidgetItem()
        self.fit_intercept_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.fit_intercept_list.addItem(item)
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.fit_intercept_list)
        self.normalizeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.normalizeLabel.setObjectName("normalizeLabel")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.normalizeLabel)
        self.normalize_list = QtWidgets.QListWidget(self.formGroupBox)
        self.normalize_list.setMaximumSize(QtCore.QSize(16777215, 50))
        self.normalize_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.normalize_list.setObjectName("normalize_list")
        item = QtWidgets.QListWidgetItem()
        self.normalize_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.normalize_list.addItem(item)
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.normalize_list)
        self.force_positive_list = QtWidgets.QListWidget(self.formGroupBox)
        self.force_positive_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.force_positive_list.setObjectName("force_positive_list")
        item = QtWidgets.QListWidgetItem()
        self.force_positive_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.force_positive_list.addItem(item)
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.force_positive_list)
        self.force_positive_label = QtWidgets.QLabel(self.formGroupBox)
        self.force_positive_label.setObjectName("force_positive_label")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.force_positive_label)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.formGroupBox.setToolTip(("<html><head/><body><p>Least-angle regression (LARS) is a regression algorithm for high-dimensional data, developed by Bradley Efron, Trevor Hastie, Iain Johnstone and Robert Tibshirani. LARS is similar to forward stepwise regression. At each step, it finds the predictor most correlated with the response. When there are multiple predictors having equal correlation, instead of continuing along the same predictor, it proceeds in a direction equiangular between the predictors.</p><p><span style=\" font-weight:600;\">The advantages of LARS are:</span></p><p>It is numerically efficient in contexts where p &gt;&gt; n (i.e., when the number of dimensions is significantly greater than the number of points)</p><p>It is computationally just as fast as forward selection and has the same order of complexity as an ordinary least squares.</p><p>It produces a full piecewise linear solution path, which is useful in cross-validation or similar attempts to tune the model.</p><p>If two variables are almost equally correlated with the response, then their coefficients should increase at approximately the same rate. The algorithm thus behaves as intuition would expect, and also is more stable.</p><p>It is easily modified to produce solutions for other estimators, like the Lasso.</p><p><span style=\" font-weight:600;\">The disadvantages of the LARS method include:</span></p><p>Because LARS is based upon an iterative refitting of the residuals, it would appear to be especially sensitive to the effects of noise. This problem is discussed in detail by Weisberg in the discussion section of the Efron et al. (2004) Annals of Statistics article.</p></body></html>"))
        self.alphaLabel.setText(("Min Alpha"))
        self.maxalpha_label.setText(("Max Alpha"))
        self.nalpha_label.setText(("# of Alphas"))
        self.max_iterLabel.setText(("Max # of iterations"))
        self.fit_interceptLabel.setText(("Fit Intercept"))
        __sortingEnabled = self.fit_intercept_list.isSortingEnabled()
        self.fit_intercept_list.setSortingEnabled(False)
        item = self.fit_intercept_list.item(0)
        item.setText(("True"))
        item = self.fit_intercept_list.item(1)
        item.setText(("False"))
        self.fit_intercept_list.setSortingEnabled(__sortingEnabled)
        self.normalizeLabel.setText(("Normalize"))
        __sortingEnabled = self.normalize_list.isSortingEnabled()
        self.normalize_list.setSortingEnabled(False)
        item = self.normalize_list.item(0)
        item.setText(("True"))
        item = self.normalize_list.item(1)
        item.setText(("False"))
        self.normalize_list.setSortingEnabled(__sortingEnabled)
        __sortingEnabled = self.force_positive_list.isSortingEnabled()
        self.force_positive_list.setSortingEnabled(False)
        item = self.force_positive_list.item(0)
        item.setText(("True"))
        item = self.force_positive_list.item(1)
        item.setText(("False"))
        self.force_positive_list.setSortingEnabled(__sortingEnabled)
        self.force_positive_label.setText(("Force Positive"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




import pickle

from PyQt5 import QtWidgets, QtGui

from point_spectra_gui.ui.RestoreTrainedModel import Ui_Form
from point_spectra_gui.util.Modules import Modules


class RestoreTrainedModel(Ui_Form, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        Modules.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        self.retorePushButton.clicked.connect(lambda: self.on_restorePushButton_clicked(self.restoreLineEdit))

    def run(self):
        # load pickled data
        filename = self.restoreLineEdit.text()
        with open(filename, 'rb') as fp:
            load = pickle.load(fp)
        self.modelkeys.append(load[0])
        self.models[load[0]] = load[1]
        pass

    def on_restorePushButton_clicked(self, lineEdit):
        # list[0] will hold the dictionary data of the UI
        # list[1] will hold the self.models data
        # load the json file into the restoreTextBrowser
        filename, _filter = QtWidgets.QFileDialog.getOpenFileName(None, "Open Data File", self.outpath, "(*.tram)")
        lineEdit.setText(filename)
        if lineEdit.text() == "":
            lineEdit.setText("*.tram")
        # Load the json file into the restoreTextBrowser to be viewed
        with open(filename, 'rb') as fp:
            output = pickle.load(fp)[0]
            self.display(output)

    def on_detailsPushButton_clicked(self):
        pass

    def display(self, text):
        cursor = self.restoreTextBrowser.textCursor()
        cursor.movePosition(QtGui.QTextCursor.End)
        cursor.insertText(text)
        self.restoreTextBrowser.setTextCursor(cursor)
        self.restoreTextBrowser.ensureCursorVisible()


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = RestoreTrainedModel()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.fitInterceptLabel = QtWidgets.QLabel(self.formGroupBox)
        self.fitInterceptLabel.setObjectName("fitInterceptLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.fitInterceptLabel)
        self.fitInterceptCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.fitInterceptCheckBox.setObjectName("fitInterceptCheckBox")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.fitInterceptCheckBox)
        self.normalizeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.normalizeLabel.setObjectName("normalizeLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.normalizeLabel)
        self.normalizeCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.normalizeCheckBox.setObjectName("normalizeCheckBox")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.normalizeCheckBox)
        self.n_coef_label = QtWidgets.QLabel(self.formGroupBox)
        self.n_coef_label.setObjectName("n_coef_label")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.n_coef_label)
        self.n_coef_spin = QtWidgets.QSpinBox(self.formGroupBox)
        self.n_coef_spin.setMaximum(999999999)
        self.n_coef_spin.setProperty("value", 100)
        self.n_coef_spin.setObjectName("n_coef_spin")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.n_coef_spin)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.formGroupBox.setTitle(("OMP"))
        self.fitInterceptLabel.setText(("Fit Intercept"))
        self.fitInterceptCheckBox.setToolTip(_translate("Form", "whether to calculate the intercept for this model. If set to false,\n"
"no intercept will be used in calculations (e.g. data is expected to\n"
"be already centered)."))
        self.fitInterceptCheckBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.OrthogonalMatchingPursuit.html"))
        self.normalizeLabel.setText(("Normalize"))
        self.normalizeCheckBox.setToolTip(_translate("Form", "This parameter is ignored when fit_intercept is set to False. If True,\n"
"the regressors X will be normalized before regression by subtracting\n"
"the mean and dividing by the l2-norm. If you wish to standardize,\n"
"please use sklearn.preprocessing.StandardScaler before calling fit on\n"
"an estimator with normalize=False."))
        self.normalizeCheckBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.OrthogonalMatchingPursuit.html"))
        self.n_coef_label.setText(("# coefficients"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets
from sklearn.linear_model.least_angle import LassoLars, LassoLarsCV, LassoLarsIC

from point_spectra_gui.ui.LassoLARS import Ui_Form
from point_spectra_gui.util.Modules import Modules


class Ui_Form(Ui_Form, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.formGroupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        # LassoLARS
        ll = LassoLars()
        self.alpha_text.setText(str(ll.alpha))
        self.fit_interceptCheckBox.setChecked(ll.fit_intercept)
        self.normalizeCheckBox.setChecked(ll.normalize)
        self.max_iterSpinBox.setValue(ll.max_iter)
        self.positiveCheckBox.setChecked(ll.positive)

    def run(self):
            params = {
                'alpha': self.alpha_text.text(),
                'fit_intercept': self.fit_interceptCheckBox.isChecked(),
                'verbose': False,
                'normalize': self.normalizeCheckBox.isChecked(),
                'precompute': True,
                'max_iter': self.max_iterSpinBox.value(),
                'copy_X': True,
                'fit_path': True,
                'positive': self.positiveCheckBox.isChecked()
            }
            params_check=dict(params)
            return params, self.getChangedValues(params_check, LassoLars())


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



import numpy as np
from PyQt5 import QtWidgets

from point_spectra_gui.ui.Normalization import Ui_Form
from point_spectra_gui.util.Modules import Modules
from point_spectra_gui.util.spectral_data import spectral_data
from libpysat.transform.norm import norm

class norm_range:
    def __init__(self, minLabel, minSpin, maxLabel, maxSpin, hidden):
        self.minLabel = minLabel
        self.minSpin = minSpin
        self.maxLabel = maxLabel
        self.maxSpin = maxSpin
        self.hidden = hidden
        self.hidden.setHidden(True)
        self.hidden.stateChanged.connect(self.Hidden)
        self.setLimits(0.0, 9999999.0)

    def Hidden(self):
        if self.hidden.isChecked():
            self.minLabel.setHidden(True)
            self.minSpin.setHidden(True)
            self.maxLabel.setHidden(True)
            self.maxSpin.setHidden(True)
        else:
            self.minLabel.setHidden(False)
            self.minSpin.setHidden(False)
            self.maxLabel.setHidden(False)
            self.maxSpin.setHidden(False)

    def getValues(self):
        return self.minSpin.value(), self.maxSpin.value()

    def setLimits(self, min, max):
        self.minSpin.setMinimum(min)
        self.maxSpin.setMinimum(min)
        self.minSpin.setMaximum(max)
        self.maxSpin.setMaximum(max)

    def setValue(self, int_):
        self.minSpin.setValue(int_)
        self.maxSpin.setValue(int_)


class Normalization(Ui_Form, Modules):
    def setupUi(self, Form, restore=False):
        if restore:
            self.restored = True
        super().setupUi(Form)
        self.setup_norm_ranges()
        self.index.setHidden(True)
        Modules.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def setup_norm_ranges(self):
        self.ranges = [norm_range(self.minWvlLabel, self.minWvlSpin, self.maxWvlLabel, self.maxWvlSpin,
                                  self.hidden_1),
                       norm_range(self.minWvlLabel_2, self.minWvlSpin_2, self.maxWvlLabel_2, self.maxWvlSpin_2,
                                  self.hidden_2),
                       norm_range(self.minWvlLabel_3, self.minWvlSpin_3, self.maxWvlLabel_3, self.maxWvlSpin_3,
                                  self.hidden_3),
                       norm_range(self.minWvlLabel_4, self.minWvlSpin_4, self.maxWvlLabel_4, self.maxWvlSpin_4,
                                  self.hidden_4),
                       norm_range(self.minWvlLabel_5, self.minWvlSpin_5, self.maxWvlLabel_5, self.maxWvlSpin_5,
                                  self.hidden_5),
                       norm_range(self.minWvlLabel_6, self.minWvlSpin_6, self.maxWvlLabel_6, self.maxWvlSpin_6,
                                  self.hidden_6),
                       norm_range(self.minWvlLabel_7, self.minWvlSpin_7, self.maxWvlLabel_7, self.maxWvlSpin_7,
                                  self.hidden_7),
                       norm_range(self.minWvlLabel_8, self.minWvlSpin_8, self.maxWvlLabel_8, self.maxWvlSpin_8,
                                  self.hidden_8),
                       norm_range(self.minWvlLabel_9, self.minWvlSpin_9, self.maxWvlLabel_9, self.maxWvlSpin_9,
                                  self.hidden_9),
                       norm_range(self.minWvlLabel_10, self.minWvlSpin_10, self.maxWvlLabel_10, self.maxWvlSpin_10,
                                  self.hidden_10),
                       norm_range(self.minWvlLabel_11, self.minWvlSpin_11, self.maxWvlLabel_11, self.maxWvlSpin_11,
                                  self.hidden_11),
                       norm_range(self.minWvlLabel_12, self.minWvlSpin_12, self.maxWvlLabel_12, self.maxWvlSpin_12,
                                  self.hidden_12),
                       norm_range(self.minWvlLabel_13, self.minWvlSpin_13, self.maxWvlLabel_13, self.maxWvlSpin_13,
                                  self.hidden_13),
                       norm_range(self.minWvlLabel_14, self.minWvlSpin_14, self.maxWvlLabel_14, self.maxWvlSpin_14,
                                  self.hidden_14),
                       norm_range(self.minWvlLabel_15, self.minWvlSpin_15, self.maxWvlLabel_15, self.maxWvlSpin_15,
                                  self.hidden_15)]
        self.spin_list = []
        for i in self.ranges:
            self.spin_list.append(i.minSpin)
            self.spin_list.append(i.maxSpin)
            i.hidden.setChecked(True)
        self.ranges[0].hidden.setChecked(False)

    def setDataLimits(self):
        # if the data exists, get the min and max of the data and use as the limits for the ranges
        datamin = 0.0
        datamax = 9999999.0
        try:
            data = self.data[self.chooseDataComboBox.currentText()]
            tempmin = np.min(data.df[self.varToNormalizeListWidget.currentItem().text()].columns.values)
            tempmax = np.max(data.df[self.varToNormalizeListWidget.currentItem().text()].columns.values)
            if type(tempmin) is not str:
                datamin = tempmin
            if type(tempmax) is not str:
                datamax = tempmax
        except:
            pass

        for i in range(len(self.ranges)):
            self.ranges[i].setLimits(datamin, datamax)
        try:
            if type(tempmin) is not str:
                self.setDataRanges()
        except:
            pass

    def setDataRanges(self):
        x = self.data[self.chooseDataComboBox.currentText()].df[self.varToNormalizeListWidget.currentItem().text()].columns.values
        # borrowed this from baseline removal code, which in turn borrowed from matplotlib's boxplot outlier detection.
        d = np.diff(x)
        q1, q3 = np.percentile(d, (25, 75))
        cutoff = q3 + 1.5 * (q3 - q1)
        inds, = np.where(d > cutoff)
        xvals = (x[inds] + x[inds + 1]) / 2.0  # set values to the middle of the gaps
        xvals = np.append(xvals, np.max(x))
        self.index.setValue(len(xvals))
        print('index set to ' + str(self.index.value()))
        for i, val in enumerate(xvals):
            self.ranges[i].maxSpin.setValue(val)
            self.ranges[i].hidden.setChecked(False)

    def updateVal(self):
        # step through the spinboxes and make sure that each successive box value is
        # greater than or equal to the one before it
        for i in range(1, len(self.spin_list)):
            if self.spin_list[i].value() < self.spin_list[i - 1].value():
                self.spin_list[i].setValue(self.spin_list[i - 1].value())

    def connectWidgets(self):
        """
        populate combobox with dataset names
        update list of variables to normalize when data set selection is changed
        when the variable to normalize is changed, update the min max and default norm ranges
        when anything in the gui is changed, run update val to make sure values are increasing
        connect the add and delete ranges buttons
        :param self:
        :return:
        """
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.changeComboListVars(self.varToNormalizeListWidget, self.xvar_choices())
        self.varToNormalizeListWidget.itemSelectionChanged.connect(self.setDataLimits)
        # when anything in the gui is changed, run update val to make sure values are increasing
        self.qtickle.guiChanged(self.updateVal)
        self.chooseDataComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.varToNormalizeListWidget, self.xvar_choices()))
        # connect the add and delete ranges buttons
        self.add_range_button.clicked.connect(lambda: self.on_addRange_pushed())
        self.delete_range_button.clicked.connect(lambda: self.on_deleteRange_pushed())

    def on_addRange_pushed(self):
        if self.index.value() < len(self.ranges):
            self.ranges[self.index.value()].hidden.setChecked(False)
            self.index.setValue(self.index.value() + 1)
            print('Index is now: ' + str(self.index.value()))
        else:
            print("Cannot add more ranges!")

    def on_deleteRange_pushed(self):
        if self.index.value() > 1:
            self.index.setValue(self.index.value() - 1)
            self.ranges[self.index.value()].hidden.setChecked(True)
            print('Index is now: ' + str(self.index.value()))
        else:
            print("Cannot delete any more ranges!")

    def run(self):
        datakey = self.chooseDataComboBox.currentText()
        range_vals = []
        for i in self.ranges:
            range_min, range_max = i.getValues()
            if range_min != range_max:
                range_vals.append([range_min, range_max])
                pass
        try:
            col_var = self.varToNormalizeListWidget.currentItem().text()
            self.data[datakey]=spectral_data(norm(self.data[datakey].df,range_vals, col_var))
            print("Normalization has been applied to the ranges: " + str(range_vals))
            print("{}".format(range_vals))
        except Exception as e:
            print(str(e) + ": Did you remember to select a variable?")

    def xvar_choices(self):
        try:
            try:
                xvarchoices = self.data[self.chooseDataComboBox.currentText()].df.columns.levels[
                    0].values
            except:
                xvarchoices = self.data[self.chooseDataComboBox.currentText()].columns.values
            xvarchoices = [i for i in xvarchoices if not 'Unnamed' in i]  # remove unnamed columns from choices
        except:
            xvarchoices = ['No valid choices!']
        return xvarchoices


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = Normalization()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from PyQt5 import QtWidgets

from point_spectra_gui.util import Qtickle
from point_spectra_gui.core.clusteringMethods import *
from point_spectra_gui.ui.Clustering import Ui_Form
from point_spectra_gui.util.Modules import Modules
from libpysat.clustering.cluster import cluster
from point_spectra_gui.util.spectral_data import spectral_data


class Clustering(Ui_Form, Modules):
    def setupUi(self, Form):
        self.Form = Form
        super().setupUi(Form)
        Modules.setupUi(self, Form)
        self.clusteringMethods()

    def get_widget(self):
        return self.formGroupBox

    def connectWidgets(self):
        self.algorithm_list = ['Choose an algorithm',
                               'K-Means',
                               'Spectral'
                               ]

        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.setListWidget(self.variables_list, self.xvar_choices())
        self.chooseDataComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.variables_list, self.xvar_choices()))
        self.setComboBox(self.chooseMethodComboBox, self.algorithm_list)
        self.chooseMethodComboBox.currentIndexChanged.connect(
            lambda: self.make_cluster_widget(self.chooseMethodComboBox.currentText()))

    def getGuiParams(self):
        """
        Overriding Modules' getGuiParams, because I'll need to do a list of lists
        in order to obtain the regressionMethods' parameters
        """
        self.qt = Qtickle.Qtickle(self)
        s = []
        s.append(self.qt.guiSave())
        for items in self.alg:
            s.append(items.getGuiParams())
        return s

    def setGuiParams(self, dict):
        """
        Overriding Modules' setGuiParams, because we are accessing a list of lists
        And each submodule contains it's own `setGuiParams`
        """
        self.qt = Qtickle.Qtickle(self)
        self.qt.guiRestore(dict[0])
        for i in range(len(dict)):
            self.alg[i - 1].setGuiParams(dict[i])

    def selectiveSetGuiParams(self, dict):
        """
        Override Modules' selective Restore function

        Setup Qtickle
        selectively restore the UI, the data to do that will be in the 0th element of the dictionary
        We will then iterate through the rest of the dictionary
        Will now restore the parameters for the algorithms in the list, Each of the algs have their own selectiveSetGuiParams

        :param dict:
        :return:
        """

        self.qt = Qtickle.Qtickle(self)
        self.qt.selectiveGuiRestore(dict[0])
        for i in range(len(dict)):
            self.alg[i - 1].selectiveSetGuiParams(dict[i])

    def setup(self):
        method = self.chooseMethodComboBox.currentText()
        datakey = self.chooseDataComboBox.currentText()
        if method != 'Choose an algorithm':
            self.data[datakey].df[(method, 'Cluster')] = 99999  # create the column to hold the clustering results,
            # fill with dummy data until clustering is actually run

    def run(self):
        method = self.chooseMethodComboBox.currentText()
        datakey = self.chooseDataComboBox.currentText()
        params, modelkey = self.getMethodParams(self.chooseMethodComboBox.currentIndex())
        col = [str(i.text()) for i in self.variables_list.selectedItems()]
        self.data[datakey] = spectral_data(cluster(self.data[datakey].df, col, method, [], params))

    def make_cluster_widget(self, alg):
        self.hideAll()
        # print(alg)
        for i in range(len(self.algorithm_list)):
            if alg == self.algorithm_list[i] and i > 0:
                self.alg[i - 1].setHidden(False)

    def hideAll(self):
        for a in self.alg:
            a.setHidden(True)

    def clusteringMethods(self):
        self.alg = []
        list_forms = [cluster_KMeans,
                      cluster_Spectral]
        for items in list_forms:
            self.alg.append(items.Ui_Form())
            self.alg[-1].setupUi(self.Form)
            self.clustering_vlayout.addWidget(self.alg[-1].get_widget())
            self.alg[-1].setHidden(True)

    def getMethodParams(self, index):
        return self.alg[index - 1].run()

    def xvar_choices(self):
        try:
            try:
                xvarchoices = self.data[self.chooseDataComboBox.currentText()].df.columns.levels[0].values
            except:
                xvarchoices = self.data[self.chooseDataComboBox.currentText()].columns.values
            xvarchoices = [i for i in xvarchoices if not 'Unnamed' in i]  # remove unnamed columns from choices
        except:
            xvarchoices = ['No valid choices!']
        return xvarchoices


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = Clustering()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.cLabel = QtWidgets.QLabel(self.formGroupBox)
        self.cLabel.setObjectName("cLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.cLabel)
        self.cLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.cLineEdit.setProperty("value", 1.0)
        self.cLineEdit.setObjectName("cLineEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.cLineEdit)
        self.epsilonLabel = QtWidgets.QLabel(self.formGroupBox)
        self.epsilonLabel.setObjectName("epsilonLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.epsilonLabel)
        self.epsilonLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.epsilonLineEdit.setProperty("value", 0.1)
        self.epsilonLineEdit.setObjectName("epsilonLineEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.epsilonLineEdit)
        self.kernelLabel = QtWidgets.QLabel(self.formGroupBox)
        self.kernelLabel.setObjectName("kernelLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.kernelLabel)
        self.kernel_list = QtWidgets.QListWidget(self.formGroupBox)
        self.kernel_list.setMaximumSize(QtCore.QSize(16777215, 120))
        self.kernel_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.kernel_list.setObjectName("kernel_list")
        item = QtWidgets.QListWidgetItem()
        self.kernel_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.kernel_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.kernel_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.kernel_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.kernel_list.addItem(item)
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.kernel_list)
        self.degreeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.degreeLabel.setObjectName("degreeLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.degreeLabel)
        self.degreeLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.degreeLineEdit.setObjectName("degreeLineEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.degreeLineEdit)
        self.coeff0Label = QtWidgets.QLabel(self.formGroupBox)
        self.coeff0Label.setObjectName("coeff0Label")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.coeff0Label)
        self.coeff0LineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.coeff0LineEdit.setObjectName("coeff0LineEdit")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.coeff0LineEdit)
        self.shrinkingLabel = QtWidgets.QLabel(self.formGroupBox)
        self.shrinkingLabel.setObjectName("shrinkingLabel")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.shrinkingLabel)
        self.shrinking_list = QtWidgets.QListWidget(self.formGroupBox)
        self.shrinking_list.setMaximumSize(QtCore.QSize(16777215, 50))
        self.shrinking_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.shrinking_list.setObjectName("shrinking_list")
        item = QtWidgets.QListWidgetItem()
        self.shrinking_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.shrinking_list.addItem(item)
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.shrinking_list)
        self.toleranceLabel = QtWidgets.QLabel(self.formGroupBox)
        self.toleranceLabel.setObjectName("toleranceLabel")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.toleranceLabel)
        self.toleranceLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.toleranceLineEdit.setProperty("decimals", 3)
        self.toleranceLineEdit.setProperty("value", 0.001)
        self.toleranceLineEdit.setObjectName("toleranceLineEdit")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.toleranceLineEdit)
        self.maxIterationsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.maxIterationsLabel.setObjectName("maxIterationsLabel")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.maxIterationsLabel)
        self.maxIterationsLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.maxIterationsLineEdit.setProperty("minimum", -1)
        self.maxIterationsLineEdit.setProperty("maximum", 9999999)
        self.maxIterationsLineEdit.setProperty("value", -1)
        self.maxIterationsLineEdit.setObjectName("maxIterationsLineEdit")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.maxIterationsLineEdit)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.formGroupBox.setToolTip(("<html><head/><body><p>The method of Support Vector Classification can be extended to solve regression problems. This method is called Support Vector Regression.</p><p>The model produced by support vector classification (as described above) depends only on a subset of the training data, because the cost function for building the model does not care about training points that lie beyond the margin. Analogously, the model produced by Support Vector Regression depends only on a subset of the training data, because the cost function for building the model ignores any training data close to the model prediction.</p></body></html>"))
        self.cLabel.setText(("Penalty Parameter"))
        self.epsilonLabel.setText(("Epsilon"))
        self.kernelLabel.setText(("Kernel"))
        __sortingEnabled = self.kernel_list.isSortingEnabled()
        self.kernel_list.setSortingEnabled(False)
        item = self.kernel_list.item(0)
        item.setText(("Radial Basis Function"))
        item = self.kernel_list.item(1)
        item.setText(("Linear"))
        item = self.kernel_list.item(2)
        item.setText(("Polynomial"))
        item = self.kernel_list.item(3)
        item.setText(("Sigmoid"))
        item = self.kernel_list.item(4)
        item.setText(("Precomputed"))
        self.kernel_list.setSortingEnabled(__sortingEnabled)
        self.degreeLabel.setText(("Polynomial Degree"))
        self.coeff0Label.setText(("Coeff 0"))
        self.shrinkingLabel.setText(("Shrinking"))
        __sortingEnabled = self.shrinking_list.isSortingEnabled()
        self.shrinking_list.setSortingEnabled(False)
        item = self.shrinking_list.item(0)
        item.setText(("True"))
        item = self.shrinking_list.item(1)
        item.setText(("False"))
        self.shrinking_list.setSortingEnabled(__sortingEnabled)
        self.toleranceLabel.setText(("Tolerance"))
        self.maxIterationsLabel.setText(("Max Iterations"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.appNameLabel = QtWidgets.QLabel(Form)
        font = QtGui.QFont()
        font.setPointSize(14)
        self.appNameLabel.setFont(font)
        self.appNameLabel.setTextFormat(QtCore.Qt.AutoText)
        self.appNameLabel.setObjectName("appNameLabel")
        self.verticalLayout.addWidget(self.appNameLabel)
        self.versionLabel = QtWidgets.QLabel(Form)
        self.versionLabel.setObjectName("versionLabel")
        self.verticalLayout.addWidget(self.versionLabel)
        self.poweredByLabel = QtWidgets.QLabel(Form)
        self.poweredByLabel.setObjectName("poweredByLabel")
        self.verticalLayout.addWidget(self.poweredByLabel)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("About"))
        self.appNameLabel.setText(("PySAT Point Spectra Gui"))
        self.versionLabel.setText(("Version "))
        self.poweredByLabel.setText(("Powered by Qt for Python"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from point_spectra_gui.core.dimensionalityReductionMethods import dimred_FastICA
from point_spectra_gui.core.dimensionalityReductionMethods import dimred_JADE
from point_spectra_gui.core.dimensionalityReductionMethods import dimred_LLE
from point_spectra_gui.core.dimensionalityReductionMethods import dimred_PCA
from point_spectra_gui.core.dimensionalityReductionMethods import dimred_tSNE




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setObjectName("formLayout")
        self.numOfComponentsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.numOfComponentsLabel.setObjectName("numOfComponentsLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.numOfComponentsLabel)
        self.numOfComponentsLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.numOfComponentsLineEdit.setObjectName("numOfComponentsLineEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.numOfComponentsLineEdit)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.numOfComponentsLabel.setText(("Num of Components"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.gridLayout_2 = QtWidgets.QGridLayout()
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.colName_3 = QtWidgets.QComboBox(self.groupBox)
        self.colName_3.setObjectName("colName_3")
        self.gridLayout_2.addWidget(self.colName_3, 4, 1, 1, 1)
        self.colName_2 = QtWidgets.QComboBox(self.groupBox)
        self.colName_2.setObjectName("colName_2")
        self.gridLayout_2.addWidget(self.colName_2, 3, 1, 1, 1)
        self.colName_5 = QtWidgets.QComboBox(self.groupBox)
        self.colName_5.setObjectName("colName_5")
        self.gridLayout_2.addWidget(self.colName_5, 6, 1, 1, 1)
        self.value_3 = QtWidgets.QComboBox(self.groupBox)
        self.value_3.setObjectName("value_3")
        self.gridLayout_2.addWidget(self.value_3, 4, 3, 1, 1)
        self.colName_1 = QtWidgets.QComboBox(self.groupBox)
        self.colName_1.setObjectName("colName_1")
        self.gridLayout_2.addWidget(self.colName_1, 2, 1, 1, 1)
        self.operator_1 = QtWidgets.QComboBox(self.groupBox)
        self.operator_1.setObjectName("operator_1")
        self.operator_1.addItem("")
        self.operator_1.addItem("")
        self.operator_1.addItem("")
        self.operator_1.addItem("")
        self.operator_1.addItem("")
        self.gridLayout_2.addWidget(self.operator_1, 2, 2, 1, 1)
        self.logic_2 = QtWidgets.QComboBox(self.groupBox)
        self.logic_2.setObjectName("logic_2")
        self.logic_2.addItem("")
        self.logic_2.addItem("")
        self.logic_2.addItem("")
        self.gridLayout_2.addWidget(self.logic_2, 3, 4, 1, 1)
        self.operator_4 = QtWidgets.QComboBox(self.groupBox)
        self.operator_4.setObjectName("operator_4")
        self.operator_4.addItem("")
        self.operator_4.addItem("")
        self.operator_4.addItem("")
        self.operator_4.addItem("")
        self.operator_4.addItem("")
        self.gridLayout_2.addWidget(self.operator_4, 5, 2, 1, 1)
        self.value_1 = QtWidgets.QComboBox(self.groupBox)
        self.value_1.setObjectName("value_1")
        self.gridLayout_2.addWidget(self.value_1, 2, 3, 1, 1)
        self.value_2 = QtWidgets.QComboBox(self.groupBox)
        self.value_2.setObjectName("value_2")
        self.gridLayout_2.addWidget(self.value_2, 3, 3, 1, 1)
        self.operator_3 = QtWidgets.QComboBox(self.groupBox)
        self.operator_3.setObjectName("operator_3")
        self.operator_3.addItem("")
        self.operator_3.addItem("")
        self.operator_3.addItem("")
        self.operator_3.addItem("")
        self.operator_3.addItem("")
        self.gridLayout_2.addWidget(self.operator_3, 4, 2, 1, 1)
        self.value_5 = QtWidgets.QComboBox(self.groupBox)
        self.value_5.setObjectName("value_5")
        self.gridLayout_2.addWidget(self.value_5, 6, 3, 1, 1)
        self.operator_2 = QtWidgets.QComboBox(self.groupBox)
        self.operator_2.setObjectName("operator_2")
        self.operator_2.addItem("")
        self.operator_2.addItem("")
        self.operator_2.addItem("")
        self.operator_2.addItem("")
        self.operator_2.addItem("")
        self.gridLayout_2.addWidget(self.operator_2, 3, 2, 1, 1)
        self.colName_4 = QtWidgets.QComboBox(self.groupBox)
        self.colName_4.setObjectName("colName_4")
        self.gridLayout_2.addWidget(self.colName_4, 5, 1, 1, 1)
        self.logic_1 = QtWidgets.QComboBox(self.groupBox)
        self.logic_1.setObjectName("logic_1")
        self.logic_1.addItem("")
        self.logic_1.addItem("")
        self.logic_1.addItem("")
        self.gridLayout_2.addWidget(self.logic_1, 2, 4, 1, 1)
        self.chooseData = QtWidgets.QComboBox(self.groupBox)
        self.chooseData.setObjectName("chooseData")
        self.gridLayout_2.addWidget(self.chooseData, 0, 2, 1, 1)
        self.chooseDataLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.gridLayout_2.addWidget(self.chooseDataLabel, 0, 1, 1, 1)
        self.remove_label = QtWidgets.QLabel(self.groupBox)
        self.remove_label.setObjectName("remove_label")
        self.gridLayout_2.addWidget(self.remove_label, 1, 1, 1, 1)
        self.logic_4 = QtWidgets.QComboBox(self.groupBox)
        self.logic_4.setObjectName("logic_4")
        self.logic_4.addItem("")
        self.logic_4.addItem("")
        self.logic_4.addItem("")
        self.gridLayout_2.addWidget(self.logic_4, 5, 4, 1, 1)
        self.value_4 = QtWidgets.QComboBox(self.groupBox)
        self.value_4.setObjectName("value_4")
        self.gridLayout_2.addWidget(self.value_4, 5, 3, 1, 1)
        self.operator_5 = QtWidgets.QComboBox(self.groupBox)
        self.operator_5.setObjectName("operator_5")
        self.operator_5.addItem("")
        self.operator_5.addItem("")
        self.operator_5.addItem("")
        self.operator_5.addItem("")
        self.operator_5.addItem("")
        self.gridLayout_2.addWidget(self.operator_5, 6, 2, 1, 1)
        self.logic_3 = QtWidgets.QComboBox(self.groupBox)
        self.logic_3.setObjectName("logic_3")
        self.logic_3.addItem("")
        self.logic_3.addItem("")
        self.logic_3.addItem("")
        self.gridLayout_2.addWidget(self.logic_3, 4, 4, 1, 1)
        self.hidden_2 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_2.setObjectName("hidden_2")
        self.gridLayout_2.addWidget(self.hidden_2, 3, 5, 1, 1)
        self.hidden_3 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_3.setObjectName("hidden_3")
        self.gridLayout_2.addWidget(self.hidden_3, 4, 5, 1, 1)
        self.hidden_4 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_4.setObjectName("hidden_4")
        self.gridLayout_2.addWidget(self.hidden_4, 5, 5, 1, 1)
        self.hidden_5 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_5.setObjectName("hidden_5")
        self.gridLayout_2.addWidget(self.hidden_5, 6, 5, 1, 1)
        self.gridLayout.addLayout(self.gridLayout_2, 4, 0, 1, 1)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Remove Rows"))
        self.operator_1.setItemText(0, ("="))
        self.operator_1.setItemText(1, (">"))
        self.operator_1.setItemText(2, ("<"))
        self.operator_1.setItemText(3, (">="))
        self.operator_1.setItemText(4, ("<="))
        self.logic_2.setItemText(0, ("-"))
        self.logic_2.setItemText(1, ("and"))
        self.logic_2.setItemText(2, ("or"))
        self.operator_4.setItemText(0, ("="))
        self.operator_4.setItemText(1, (">"))
        self.operator_4.setItemText(2, ("<"))
        self.operator_4.setItemText(3, (">="))
        self.operator_4.setItemText(4, ("<="))
        self.operator_3.setItemText(0, ("="))
        self.operator_3.setItemText(1, (">"))
        self.operator_3.setItemText(2, ("<"))
        self.operator_3.setItemText(3, (">="))
        self.operator_3.setItemText(4, ("<="))
        self.operator_2.setItemText(0, ("="))
        self.operator_2.setItemText(1, (">"))
        self.operator_2.setItemText(2, ("<"))
        self.operator_2.setItemText(3, (">="))
        self.operator_2.setItemText(4, ("<="))
        self.logic_1.setItemText(0, ("-"))
        self.logic_1.setItemText(1, ("and"))
        self.logic_1.setItemText(2, ("or"))
        self.chooseDataLabel.setText(("Choose Data:"))
        self.remove_label.setText(("Remove rows where:"))
        self.logic_4.setItemText(0, ("-"))
        self.logic_4.setItemText(1, ("and"))
        self.logic_4.setItemText(2, ("or"))
        self.operator_5.setItemText(0, ("="))
        self.operator_5.setItemText(1, (">"))
        self.operator_5.setItemText(2, ("<"))
        self.operator_5.setItemText(3, (">="))
        self.operator_5.setItemText(4, ("<="))
        self.logic_3.setItemText(0, ("-"))
        self.logic_3.setItemText(1, ("and"))
        self.logic_3.setItemText(2, ("or"))
        self.hidden_2.setText(("Hidden"))
        self.hidden_3.setText(("Hidden"))
        self.hidden_4.setText(("Hidden"))
        self.hidden_5.setText(("Hidden"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        pass


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.numOfIterationsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.numOfIterationsLabel.setObjectName("numOfIterationsLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.numOfIterationsLabel)
        self.numOfIterationsLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.numOfIterationsLineEdit.setProperty("maximum", 999999999)
        self.numOfIterationsLineEdit.setProperty("value", 300)
        self.numOfIterationsLineEdit.setObjectName("numOfIterationsLineEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.numOfIterationsLineEdit)
        self.toleranceLabel = QtWidgets.QLabel(self.formGroupBox)
        self.toleranceLabel.setObjectName("toleranceLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.toleranceLabel)
        self.toleranceLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.toleranceLineEdit.setProperty("decimals", 5)
        self.toleranceLineEdit.setProperty("singleStep", 0.001)
        self.toleranceLineEdit.setProperty("value", 0.001)
        self.toleranceLineEdit.setObjectName("toleranceLineEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.toleranceLineEdit)
        self.alpha1Label = QtWidgets.QLabel(self.formGroupBox)
        self.alpha1Label.setObjectName("alpha1Label")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.alpha1Label)
        self.alpha1LineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.alpha1LineEdit.setProperty("decimals", 5)
        self.alpha1LineEdit.setProperty("singleStep", 0.001)
        self.alpha1LineEdit.setProperty("value", 0.001)
        self.alpha1LineEdit.setObjectName("alpha1LineEdit")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.alpha1LineEdit)
        self.alpha2Label = QtWidgets.QLabel(self.formGroupBox)
        self.alpha2Label.setObjectName("alpha2Label")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.alpha2Label)
        self.alpha2LineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.alpha2LineEdit.setProperty("decimals", 8)
        self.alpha2LineEdit.setProperty("singleStep", 1e-06)
        self.alpha2LineEdit.setProperty("value", 1e-06)
        self.alpha2LineEdit.setObjectName("alpha2LineEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.alpha2LineEdit)
        self.lambdaLabel = QtWidgets.QLabel(self.formGroupBox)
        self.lambdaLabel.setObjectName("lambdaLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.lambdaLabel)
        self.lambdaLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.lambdaLineEdit.setProperty("decimals", 8)
        self.lambdaLineEdit.setProperty("singleStep", 1e-06)
        self.lambdaLineEdit.setProperty("value", 1e-06)
        self.lambdaLineEdit.setObjectName("lambdaLineEdit")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.lambdaLineEdit)
        self.lambda2_label = QtWidgets.QLabel(self.formGroupBox)
        self.lambda2_label.setObjectName("lambda2_label")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.lambda2_label)
        self.lambda2LineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.lambda2LineEdit.setObjectName("lambda2LineEdit")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.lambda2LineEdit)
        self.fitInterceptLabel = QtWidgets.QLabel(self.formGroupBox)
        self.fitInterceptLabel.setObjectName("fitInterceptLabel")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.fitInterceptLabel)
        self.fitIntercept_List = QtWidgets.QListWidget(self.formGroupBox)
        self.fitIntercept_List.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.fitIntercept_List.setObjectName("fitIntercept_List")
        item = QtWidgets.QListWidgetItem()
        self.fitIntercept_List.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.fitIntercept_List.addItem(item)
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.fitIntercept_List)
        self.normalizeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.normalizeLabel.setObjectName("normalizeLabel")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.normalizeLabel)
        self.normalize_List = QtWidgets.QListWidget(self.formGroupBox)
        self.normalize_List.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.normalize_List.setObjectName("normalize_List")
        item = QtWidgets.QListWidgetItem()
        self.normalize_List.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.normalize_List.addItem(item)
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.normalize_List)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.numOfIterationsLabel.setText(("num of iterations"))
        self.numOfIterationsLineEdit.setText(("300"))
        self.toleranceLabel.setText(("Tolerance"))
        self.toleranceLineEdit.setText(("0.001"))
        self.alpha1Label.setText(("Alpha 1"))
        self.alpha1LineEdit.setText(("0.000001"))
        self.alpha2Label.setText(("Alpha 2"))
        self.alpha2LineEdit.setText(("0.000001"))
        self.lambdaLabel.setText(("Lambda 1"))
        self.lambdaLineEdit.setText(("0.000001"))
        self.lambda2_label.setText(("Labda 2"))
        self.lambda2LineEdit.setText(("0.000001"))
        self.fitInterceptLabel.setText(("Fit Intercept"))
        __sortingEnabled = self.fitIntercept_List.isSortingEnabled()
        self.fitIntercept_List.setSortingEnabled(False)
        item = self.fitIntercept_List.item(0)
        item.setText(("True"))
        item = self.fitIntercept_List.item(1)
        item.setText(("False"))
        self.fitIntercept_List.setSortingEnabled(__sortingEnabled)
        self.normalizeLabel.setText(("Normalize"))
        __sortingEnabled = self.normalize_List.isSortingEnabled()
        self.normalize_List.setSortingEnabled(False)
        item = self.normalize_List.item(0)
        item.setText(("True"))
        item = self.normalize_List.item(1)
        item.setText(("False"))
        self.normalize_List.setSortingEnabled(__sortingEnabled)


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

